Examples
========

The following examples demonstrate how *yeoda* can be utilised for analysing various earth observation datasets.

.. toctree::
   :maxdepth: 2

   ERA-20C <notebooks/era_clim_20.ipynb>
   SCATSAR SWI <notebooks/scatsarswi.ipynb>
   Radar RGB composites <notebooks/radar_comp.ipynb>